Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(584)

Unified Diff: tools/create_tarball.py

Issue 1166743005: Remove GetSVNRevision from tools/utils.py (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: address comments Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/create_sdk.py ('k') | tools/dartium/buildbot_annotated_steps.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/create_tarball.py
diff --git a/tools/create_tarball.py b/tools/create_tarball.py
index 73d8bb855ec8593464e9e452144a4e4ea831ced8..f51e4bbbfcc8bec68836555b4a9e432bc1da49cc 100755
--- a/tools/create_tarball.py
+++ b/tools/create_tarball.py
@@ -102,9 +102,9 @@ def GenerateChangeLog(filename, version):
f.write(' -- Dart Team <misc@dartlang.org> %s\n' %
datetime.datetime.utcnow().strftime('%a, %d %b %Y %X +0000'))
-def GenerateSvnRevision(filename, svn_revision):
+def GenerateGitRevision(filename, git_revision):
with open(filename, 'w') as f:
- f.write(str(svn_revision))
+ f.write(str(git_revision))
def CreateTarball(tarfilename):
@@ -138,11 +138,11 @@ def CreateTarball(tarfilename):
GenerateChangeLog(change_log, version)
tar.add(change_log, arcname='%s/debian/changelog' % versiondir)
# For bleeding_edge add the SVN_REVISION file.
if utils.GetChannel() == 'be':
- svn_revision = join(temp_dir, 'SVN_REVISION')
- GenerateSvnRevision(svn_revision, utils.GetSVNRevision())
- tar.add(svn_revision, arcname='%s/dart/tools/SVN_REVISION' % versiondir)
+ git_revision = join(temp_dir, 'GIT_REVISION')
+ GenerateGitRevision(git_revision, utils.GetGitRevision())
+ tar.add(git_revision, arcname='%s/dart/tools/GIT_REVISION' % versiondir)
def Main():
if HOST_OS != 'linux':
« no previous file with comments | « tools/create_sdk.py ('k') | tools/dartium/buildbot_annotated_steps.py » ('j') | no next file with comments »
@@ -138,11 +138,11 @@ def CreateTarball(tarfilename):
GenerateChangeLog(change_log, version)
tar.add(change_log, arcname='%s/debian/changelog' % versiondir)
- # For bleeding_edge add the SVN_REVISION file.
+ # For bleeding_edge add the GIT_REVISION file.
if utils.GetChannel() == 'be':

Powered by Google App Engine
This is Rietveld 408576698